
%%The modelling code produces a separate .mat file for each model fit
%%result. Here I am consolidating the four runs of each model version into
%%a single mat file for further analysis and saving. I am also combining
%%all the jackknifed samples together for each model.

clear all
model = {'BurstIE', 'SustIE', 'BurstSE', 'SustSE', 'DDM'};
modelnames = {'NI_BurstIE', 'NI_SustIE', 'NI_BurstSE', 'NI_SustSE', 'DDM'};
model_versions{1} = {'_su_st', '_sz_su_st', '_su_st_boost', '_UbU_su_st',  '_Swap1', '_Swap2'};
model_versions{2} = {'_su_st', '_sz_su_st', 'db0_su_st'};
model_versions{3} = {'_su_st', '_sTev_su_st', '_sz_su_st'};
model_versions{4} = {'_su_st', '_sz_su_st', '_sTev_su_st'};
model_versions{5} = {''};

for i = 1:length(model_versions)
    mv(i) = length(model_versions{i});
end

%%The main results

for m = 1:length(model)
    
    for v = 1:length(model_versions{m})
        
        for st = 1:4 %%4 runs of each to be combined
            
            load(['Fits/JK0_' num2str(st) '_paramfits_' modelnames{m} model_versions{m}{v} '.mat'])
            
            AIC_all(st) = E_cross + 2*sum(Sel);
            G2_all(st) = E_cross;
            G2_fit_all(st) = E_ave;
            pm{st} = pm_ave;
            start_params{st} = startpms;
        end
        
        [G2 win] = min(G2_all);
        pm_est = pm{win};
        AIC = AIC_all(win);
        
        save(['All_paramfits_' modelnames{m} model_versions{m}{v} '.mat'], 'AIC_all', 'G2_all', 'G2_fit_all', 'pm', 'start_params', 'G2', 'pm_est', 'AIC', 'Sel', 'par_range', 'Dat')
    end
end

%%Jackknifed results

v=1;
for m = 1:length(model)
    
    for jk=1:17
        for st = 1:4 %%4 runs of each to be combined
            
            load(['Fits/JK' num2str(jk) '_' num2str(st) '_paramfits_' modelnames{m} model_versions{m}{v} '.mat'])
            
            JK(jk).AIC_all(st) = E_cross + 2*sum(Sel);
            JK(jk).G2_all(st) = E_cross;
            JK(jk).G2_fit_all(st) = E_ave;
            JK(jk).pm{st} = pm_ave;
            JK(jk).start_params{st} = startpms;
        end
        
        [JK(jk).G2 win] = min(JK(jk).G2_all);
        JK(jk).pm_est = JK(jk).pm{win};
        JK(jk).AIC = JK(jk).AIC_all(win);
        JK(jk).Dat = Dat;
    end
    save(['JK_paramfits_' modelnames{m} model_versions{m}{v} '.mat'], 'Sel', 'par_range', 'JK')
    
end