clear all
model = {'BurstIE', 'SustIE', 'BurstSE', 'SustSE', 'DDM'};
modelnames = {'NI_BurstIE', 'NI_SustIE', 'NI_BurstSE', 'NI_SustSE', 'DDM'};
model_versions{1} = {'_su_st', '_sz_su_st', '_su_st_boost', '_UbU_su_st',  '_Swap1', '_Swap2'};
model_versions{2} = {'_su_st', '_sz_su_st', 'db0_su_st'};
model_versions{3} = {'_su_st', '_sTev_su_st', '_sz_su_st'};
model_versions{4} = {'_su_st', '_sz_su_st', '_sTev_su_st'};
model_versions{5} = {''};

for i = 1:length(model_versions)
    mv(i) = length(model_versions{i});
end
    
    
%%Full dataset Get fits for Table 2 
aic_all = [];
g2_all=[];
for m = 1:length(model)
    for v = 1:length(model_versions{m})
        
        load(['All_paramfits_' modelnames{m} model_versions{m}{v} '.mat']);
       
       g2{m}(v) = G2;
        aic{m}(v) = AIC;
        aic_all = [aic_all; AIC];
        g2_all = [g2_all; G2];
        if v==1
            param_estimates{m} = pm_est; 
        end
    end
end

%%The models show in table 2 in order. For Akaike weight calculation
AIC_Table2 = aic_all([1 1+mv(1) 1+sum(mv(1:2)) 1+sum(mv(1:3)) 4 3+mv(1) 1+sum(mv(1:4)) 5 6 3 2 2+mv(1) 3+sum(mv(1:2)) 2+sum(mv(1:3))  2+sum(mv(1:2)) 3+sum(mv(1:3))]);
G2_Table2 = g2_all([1 1+mv(1) 1+sum(mv(1:2)) 1+sum(mv(1:3)) 4 3+mv(1) 1+sum(mv(1:4)) 5 6 3 2 2+mv(1) 3+sum(mv(1:2)) 2+sum(mv(1:3))  2+sum(mv(1:2)) 3+sum(mv(1:3))]);
[mm mi] = min(AIC_Table2);

%Akaike weights
Delta = AIC_Table2 - mm;
for i = 1:length(AIC_Table2)
W_Table2(i) = exp(-Delta(i)/2)/sum(exp(-Delta/2));
end

disp(W_Table2);



%%Comparing five main models on JackKnife fits
AIC = nan(length(model),17);
for m = 1:length(model)
    
    load(['JK_paramfits_' modelnames{m} model_versions{m}{v} '.mat']);
    
    for s = 1:17
        
               
        AIC(m,s) = JK(s).AIC;
    end
end


%Akaike weights including the 4 neurally-informed models.
for s=1:17
    [mm i] = min(AIC(:,s));
    delta(:,s) = AIC(:,s) - AIC(i,s);
    
    for m = 1:5
        w(m,s) = exp(-delta(m,s)/2)/sum(exp(-delta(1:4,s)/2));
    end
end

%%Figure 4- Figure supplement 5
figure, 
subplot(1,2,1)
plot(AIC(1:4,:), '-x', 'LineWidth', 2)
xlim([0 5])
xlabel('Model')
ylabel('AIC')
set(gca, 'LineWidth', 1, 'FontSize', 11)

box('off')
xticks(1:4);
xticklabels({'BurstIE', 'SustIE', 'BurstSE', 'SustSE'})

subplot(1,2,2)
plot(w', 'x-', 'Linewidth', 2)
ylabel('Akaike Weights')
xlabel('Participant sample')
legend({'BurstIE', 'SustIE', 'BurstSE', 'SustSE', 'DDM'})
set(gca, 'LineWidth', 1, 'FontSize', 11)
xlim([0 18])
box('off')
