%Figure 4 from main paper (model part) and
%supplemental figures 1-4. Get the first part of Figure 4 from
%Figures2_2s2_4.m

models = {'NI_BurstIE', 'NI_SustIE', 'NI_BurstSE', 'NI_SustSE', 'DDM'};
modelnames = {'NI_BurstIE_su_st', 'NI_SustIE_su_st', 'NI_BurstSE_su_st', 'NI_SustSE_su_st', 'DDM'};


for m = 1:length(models)

    model = models{m};
    
    load(['All_paramfits_' modelnames{m} '.mat']);
    disp([modelnames{m} '; G2 = ' num2str(G2)]);
    
    N =  10000*ones(4,2);  %%Number of trials to simulate
    eval(['[simdat dv t] = simul_dv_' model '(pm_est(Sel==1), pm_est(Sel==0), Sel,N);'])
    
    %%Simulated LRP decision variables
    
    if m>1
        figure,
        subplot(2,4,1)
    else
        subplot(2,6,3)
    end
    if m<5 %Difference between the 2 decision variables (neurally-informed models)
        plot(t, squeeze(dv(1,1,1,:) - dv(1,1,2,:)), 'r', 'LineWidth', 2);
        hold all
        plot(t, squeeze(dv(1,2,1,:) - dv(1,2,2,:)), 'b', 'LineWidth', 2);
        plot(t, squeeze(dv(2,1,1,:) - dv(2,1,2,:)), 'r', 'LineWidth', 1);
        plot(t, squeeze(dv(2,2,1,:) - dv(2,2,2,:)), 'b', 'LineWidth', 1);
        xlim([0.05 .29])
        xticks([ 0.05 0.15 0.25 ]);
        xticklabels({'50', '150', '250'});
    else %Just one DV in the DDM
        plot(t, squeeze(dv(1,1,:)), 'r', 'LineWidth', 2);
        hold all
        plot(t, squeeze(dv(1,2,:)), 'b', 'LineWidth', 2);
        plot(t, squeeze(dv(2,1,:)), 'r', 'LineWidth', 1);
        plot(t, squeeze(dv(2,2,:)), 'b', 'LineWidth', 1);
        xlim([0.05 .29]+0.08)
        xticks([ 0.05 0.15 0.25 ]+.080);
        xticklabels({'130', '230', '330'});
    end
    
    ylim([-.3 .8])
    ylabel('Simulated LRP');
    box('off');
    
    if m>1
        subplot(2,4,5)
    else
        subplot(2,6,9)
    end
    
    if m<5
        plot(t, squeeze(dv(3,1,1,:) - dv(3,1,2,:)), 'r', 'LineWidth', 2);
        hold all
        plot(t, squeeze(dv(3,2,1,:) - dv(3,2,2,:)), 'b', 'LineWidth', 2);
        plot(t, squeeze(dv(4,1,1,:) - dv(4,1,2,:)), 'r', 'LineWidth', 1);
        plot(t, squeeze(dv(4,2,1,:) - dv(4,2,2,:)), 'b', 'LineWidth', 1);
        xlim([0.05 .29])
        xticks([ 0.05 0.15 0.25 ]);
        xticklabels({'50', '150', '250'});
    else
        plot(t, squeeze(dv(3,1,:)), 'r', 'LineWidth', 2);
        hold all
        plot(t, squeeze(dv(3,2,:)), 'b', 'LineWidth', 2);
        plot(t, squeeze(dv(4,1,:)), 'r', 'LineWidth', 1);
        plot(t, squeeze(dv(4,2,:)), 'b', 'LineWidth', 1);
        xlim([0.05 .29]+0.08)
        xticks([ 0.05 0.15 0.25 ]+.080);
        xticklabels({'130', '230', '330'});
    end
    xlabel('Time relative to Stimulus')
    xlim([0.05 .29])
    ylim([-.3 .8])
    ylabel('Simulated LRP');
    box('off');
    
    
    %%Fits to behaviour
    histbin = [0:2/85:0.6]; % bins for histograms
    colors = [1 0 0 ; 0 0 1];
    
    N =  2*ceil(5*[hist(Dat(:,3),[1:2]); hist(Dat(:,3),[1:2]) ; hist(Dat(:,3),[1:2]) ; hist(Dat(:,3),[1:2]) ]/14);
    eval(['simdat = simul_' model '(pm_est(Sel==1), pm_est(Sel==0), Sel,N);']);
    
    conditions = unique(Dat(:,2));
    
    %order of subplots
    if m>1
        order = [2 3 6 7];
        supp=1;
    else
        order = [4 5 10 11];
        supp=0;
    end
    for i = 1:length(conditions)
        
        subplot(2,6-2*supp,order(i))
        xl = [0.05 0.58]; yl = [0 0.22]; xlim(xl); ylim(yl); yticks([0 0.1 0.2]);
        set(gca,'XTick',[]);
        
        hold on
        plotRThistRVsim(simdat(simdat(:,1)==i,2:end),histbin)     % plot RT distribution of simulated data
        plotRThistRVreal(Dat(Dat(:,2)==conditions(i),3:5), histbin)       % plot RT distribution of real data
        xl = [0.05 0.58]; xlim(xl); xticks([ 0.2  0.4 ]);
    end
    subplot(2,6-2*supp,order(1))
    ylabel('Response Probability');
    subplot(2,6-2*supp,order(3))
    ylabel('Response Probability');
    xlabel('Response time (ms)');
    
    
    %Conditional Accuracy functions (CAFs)
    
    
    xl = [0.05 0.58]; xlim(xl); xticks([0.2 0.4 ]); yticks([0 0.1 0.2]);
    color{1} = { 'r', 'm'};
    color{2} = {'b', 'c'};
    
    %%Blocked regimes
    if m>1
        subplot(2,4,4)
    else
        subplot(2,6,6)
    end
    
    hold on;
    % plot CAF of simulated data
    for i = 1:2
        data = simdat(simdat(:,1)==i,2:end);
        for c=1:2
            hc(c,:) = hist(data(find(data(:,1)==c & data(:,2)==1),3),histbin);
            he(c,:) = hist(data(find(data(:,1)==c & data(:,2)==0),3),histbin);
        end
        for c=1:2
            CAF = hc(c,:)./(hc(c,:)+he(c,:));
            CAF(find(sum([hc;he])<=40))=nan;
            plot(histbin,CAF,'Color',colors(c,:),'LineWidth',2)
        end
        % plot CAF of real data to overlay for comparison
        realdata = Dat(Dat(:,2)==conditions(i),3:5);
        hold on;
        for c=1:2
            hcr(c,:) = hist(realdata(find(realdata(:,1)==c & realdata(:,2)==1),3),histbin);
            her(c,:) = hist(realdata(find(realdata(:,1)==c & realdata(:,2)==0),3),histbin);
        end
        for c=1:2
            CAFr = hcr(c,:)./(hcr(c,:)+her(c,:));
            CAFr(find(sum([hcr;her])<=40))=nan;
            plot(histbin,CAFr,'Color',color{c}{i},'Marker','o','MarkerSize',4,'LineWidth',1,'LineStyle','none')
            xlim(xl);
        end
        
    end
    ylabel('Proportion Correct')
    xticks([ 0.2  0.4 ]); yticks([0 0.5 1]);
    %%Interleaved CAFs
    if m>1
        subplot(2,4,8)
    else
        subplot(2,6,12)
    end
    
    xl = [0.05 0.58]; xlim(xl); xticks([ 0.2 0.4 ]); yticks([0 0.5 1]);
    
    hold on;
    % plot CAF of simulated data
    for i = 3:4
        data = simdat(simdat(:,1)==i,2:end);
        for c=1:2
            hc(c,:) = hist(data(find(data(:,1)==c & data(:,2)==1),3),histbin);
            he(c,:) = hist(data(find(data(:,1)==c & data(:,2)==0),3),histbin);
        end
        for c=1:2
            CAF = hc(c,:)./(hc(c,:)+he(c,:));
            CAF(find(sum([hc;he])<=40))=nan;
            plot(histbin,CAF,'Color',colors(c,:),'LineWidth',2)
        end
        % plot CAF of real data to overlay for comparison
        realdata = Dat(Dat(:,2)==conditions(i),3:5);
        hold on;
        for c=1:2
            hcr(c,:) = hist(realdata(find(realdata(:,1)==c & realdata(:,2)==1),3),histbin);
            her(c,:) = hist(realdata(find(realdata(:,1)==c & realdata(:,2)==0),3),histbin);
        end
        for c=1:2
            CAFr = hcr(c,:)./(hcr(c,:)+her(c,:));
            CAFr(find(sum([hcr;her])<=40))=nan;
            plot(histbin,CAFr,'Color',color{c}{i-2},'Marker','o','MarkerSize',4,'LineWidth',1,'LineStyle','none')
            xlim(xl);
        end
        
    end
    ylabel('Proportion Correct')
    xlabel({'Response time (ms)'});
    
    
end










