%%%Script for running model comparison with Jack-knifed data.


%%%setting up the models to run and choice of participants
%%clear all
%%%modelstoRun = 1; %model = {'BurstIE', 'SustIE', 'BurstSE', 'SustSE', 'DDM'};
%%%versiosntorun = 1; %specific to each model
%%stages = 1:3; % How many runs? stages indexes the run number in the
%%output mat file,.
%%S_jk = 0; defining choice of participants
%%%S_jk=0 excludes the 10th subject only (final choice of participants), for S_jk between 1 and 17, exclude another;


%%Load neural constraints and select based on participant subgroup
load('BetaConstraints.mat')  %%
use_sbj = Constraints(S_jk+1).subjects;  %choice of participants.
Gp_Slope = -Constraints(S_jk+1).Gp_Slope; %change from negative to positive
Gp_sp750_contra =  Constraints(S_jk+1).Gp_sp750_contra;
Gp_sp750_ipsi =  Constraints(S_jk+1).Gp_sp750_ipsi;

load RVBDotsBigBehav % allsbj & BigBehav has 6 columns: subject number, condition, where is high value option(L/R), cue direction(L/R), response(L/R), Response Time(sec)
BigBehav(~ismember(BigBehav(:,1), use_sbj),:) = [];
%conditions: 1: HiCoh Fast; 2: LoCoh Slow; 3: HiCoh interleaved; 4 LoCoh
%interleaved


deadline = [.365 .475 .475 .475];
titles = {'HiCoh blocked', 'LoCoh blocked', 'HiCoh interleaved', 'LoCoh interleaved'};

%% Model stuff
numsbj=length(use_sbj);
% define quantiles
qps = [.1 .3 .5 .7 .9];
model = {'BurstIE', 'SustIE', 'BurstSE', 'SustSE', 'DDM'};
modelnames = {'NI_BurstIE', 'NI_SustIE', 'NI_BurstSE', 'NI_SustSE', 'DDM'};

Dat = [BigBehav(:,1) BigBehav(:,2) ~(BigBehav(:,4)==BigBehav(:,3))+1 (BigBehav(:,4)==BigBehav(:,5)) BigBehav(:,6)];  %Participant, Condition, Value (1=high, 2 = low), Correct, RT
Dat(find(Dat(:,5)<=0.05 | (Dat(:,5)>=0.6 & BigBehav(:,2)==1) | (Dat(:,5)>=0.78 & BigBehav(:,2)>1)),:) = []; % exclude anticipatory and miss trials from data to be fitted
[gdat] = makeSummaryStructure_ave(Dat,qps); % place data in a summary structure for model fitting Quantile averaged for condition

%Ordering of regime neurally-constrained parameters for the constraints-swap test
%A: hicoh, B: locoh, C: interleaved
fixed_param_mix{1} = [1:21]; %ABC
fixed_param_mix{2} = [3 4 5 6 1 2  9 10  11 12 7 8 13:15 17  18 16 20 21 19]; %BCA
fixed_param_mix{3} = [5 6 1 2 3 4 11 12 7  8  9 10 13:15 18 16  17 21 19 20]; %CAB

for m=modelstoRun
    switch m
        case 1  %BurstIE
         
            par_range = [zeros(12,2);...  % First 12 parameters fixed by neural data (starting levels and starting times)
                0.05 0.095; ...             %13 mT 1
                0.05 0.095; ...             %14 mT 2
                0.05 0.095; ...             %15 mT 3
                0.5 1.5; ...                %16 MDU 1
                0.5 1.5; ...                %17 MDU 2
                0.5 1.5; ...                %18 MDU 3
                -0.5 1;...           % 19 MDUb 1
                -0.5 1;...           % 20 MDUb 2
                -0.5 1;...           % 21 MDUb 3
                0 0.2;...           % 22 sz
                0 25;...             % 23 d(1)
                0 25;...             % 24 d(2)
                -3 3;...            %25 dboost
                0 10;...              % 26 dC(1)
                0 10;...              % 27 dC (2)
                0 10;...              % 28 dC (3)
                0 3;...            % 29 s1  noise
                0.09 0.1; ... %30 Tac
                0.01 0.08; ... %31 burst range
                0 0.15; ...  % 32 st
                0 0.5; ...   %33 su
                3 80; ...   %34 Beta
                1 10; ];   %35 n
             
            model_versions{m} = {'_su_st', '_sz_su_st', '_su_st_boost', '_UbU_su_st',  '_Swap1', '_Swap2'};
            %modes: each element corresponds to a model version
            urgency_mode = [1 1 1 2 1 1]; %1: constrained, 2: unconstrained and unbiased
            swap_mode = [1 1 1 1 2 3];     %1: ABC; 2: BCA; % 3: CAB
  
            sps =[Gp_sp750_contra(1:3)'; Gp_sp750_ipsi(1:3)']; %Beta startpoints,  contra and ipsi to high value
            Fixed_params = [sps(:)' 750/1000*ones(1,6)];        %startpoints all set at 750ms post value cue
            
            %Indices for parameters that can either be fixed or estimated
            %depending on the model version
            Seli{m}{1} = 13:15; %motor times
            Seli{m}{2} = 16:18; %MDU
            Seli{m}{3} = 19:21; %MDUb
            Seli{m}{4} = [22 32:33]; % sz st and su
            Seli{m}{5} = [25 31]; %Drift boost, burstrange
            MDUindex{m} = 16:21;
            bdurindx{m} = 31;
            
            %%psel indicates which of the parameters are fixed (0) or
            %%variable (1) in the different model versions
            psel{m}{1, 1} = {[1 1 1], [1 1 1], [1 1 1], [1 1 1] ,[1 1 1], [1 1 1]};%Motor times
            psel{m}{2, 1} = {[0 0 0], [0 0 0],  [0 0 0],[1 1 1], [0 0 0], [0 0 0]}; %MDU
            psel{m}{3, 1} = {[0 0 0], [0 0 0], [0 0 0], [0 0 0], [0 0 0], [0 0 0]}; %MDUb
            psel{m}{4, 1} = {[0 1 1], [1 1 1], [0 1 1], [0 1 1],[0 1 1],[0 1 1]}; %variability sz, st, su
            psel{m}{5, 1} = {[0 0],   [0 0 ], [1 0 ], [0 0] ,[0 0], [0 0 ]};  %%drift boost and burstrange
            checkselzero{m} = [22  25 32:33];  %If fixed, set these params to zero
             
        case 2   %SustIE
            
            par_range = [zeros(12,2);...  % First 12 parameters fixed by neural data
                0.05 0.095; ...              %13 mT 1
                0.05 0.095; ...              %14 mT 2
                0.05 0.095; ...              %15 mT 3
                0.5 1.5; ...                %16 MDU 1
                0.5 1.5; ...                %17 MDU 2
                0.5 1.5; ...                %18 MDU 3
                -0.5 1;...           % 19 MDUb 1
                -0.5 1;...           % 20 MDUb 2
                -0.5 1;...           % 21 MDUb 3
                0 0.2;...           % 22 sz
                0 25;...             % 23 d(1)
                0 25;...             % 24 d(2)
                0 10;...              % 25 dC(1)
                0 10;...              % 26 dC (2)
                0 10;...              % 27 dC (3)
                0 3;...            % 28 s1 asymptotic noise
                0.09 0.1; ... %29 Tac
                0 0.15; ...  %30 st
                0 0.5; ...   %31 su
                3 80; ...   %32 Beta
                1 10];   %33 n
               
  
            
            model_versions{m} = {'_su_st', '_sz_su_st', 'db0_su_st'};
            urgency_mode = ones(1, length(model_versions{m})); %urgency params all fixed
            swap_mode = ones(1, length(model_versions{m}));     %no constraints swap
            

            sps =[Gp_sp750_contra(1:3)'; Gp_sp750_ipsi(1:3)'];  %Beta startpoints,  contra and ipsi to high value
            Fixed_params = [sps(:)' 750/1000*ones(1,6)]; %startpoints all set at 750ms post value cue
            
            %Indices for parameters that can either be fixed or estimated
            %depending on the model version
            Seli{m}{1} = 13:15; %motor times
            Seli{m}{2} = 16:18; %MDUc
            Seli{m}{3} = 19:21; %MDUb
            Seli{m}{4} = [22 30 31]; % sz   su st 
            Seli{m}{5} = [25:27]; % drift rate bias
            MDUindex{m} = 16:21;
 
             %%psel indicates which of the parameters are fixed (0) or
            %%variable (1) in the different model versions
            psel{m}{1, 1} = {[1 1 1 ], [1 1 1 ],  [1 1 1 ]};%Motor times
            psel{m}{2, 1} = {[0 0 0], [0 0 0], [0 0 0]}; %MDU
            psel{m}{3, 1} = {[0 0 0], [0 0 0], [0 0 0]}; %MDUb
            psel{m}{4, 1} = {[0 1 1],[1 1 1],[0 1 1]}; %variability sz   su st 
            psel{m}{5, 1} = {[1 1 1 ],[1 1  1],[0 0 0]}; %drift rate bias
            checkselzero{m} = [22 25:27 30:31];  %If fixed, set these params to zero
            bdurindx{m}=[];
            
             case {3}   %BurstSE
          
            par_range = [zeros(12,2);...  % First 12 parameters fixed by neural data
                0.05 0.095; ...             %13 mT 1
                0.05 0.095; ...             %14 mT 2
                0.05 0.095; ...             %15 mT 3
                0.5 1.5; ...                %16 MDU 1
                0.5 1.5; ...                %17 MDU 2
                0.5 1.5; ...                %18 MDU 3
                -0.5 1;...           % 19 MDUb 1
                -0.5 1;...           % 20 MDUb 2
                -0.5 1;...           % 21 MDUb 3
                0 0.2;...           % 22 sz
                0 25;...             % 23 d(1)
                0 25;...             % 24 d(2)
                0 10;...              % 25 dC(1)
                0 10;...              % 26 dC (2)
                0 10;...              % 27 dC (3)
                0 3;...            % 28 s1 within trial noise
                0.09 0.1; ... % 29 Tac accumulation onset time
                0.01 0.08; ... %30 burst range
                0 0.2; ...  % 31 st
                0 0.5; ...   %32 su
                0 0.25; ...   %33 Tev evidence onset relative to Tac
                0 0.2];  %34 sTev
               
        
            model_versions{m} = {'_su_st', '_sTev_su_st', '_sz_su_st'};
            urgency_mode = ones(1, length(model_versions{m}));  %urgency params all fixed
            swap_mode = ones(1, length(model_versions{m})); %no constraints swap
            
   
            
            sps =[Gp_sp750_contra(1:3)'; Gp_sp750_ipsi(1:3)'];   %Beta startpoints,  contra and ipsi to high value
            Fixed_params = [sps(:)' 750/1000*ones(1,6)];     %startpoints all set at 750ms post value cue
            
            Seli{m}{1} = 13:15; %motor times
            Seli{m}{2} = 16:18; %MDU
            Seli{m}{3} = 19:21; %MDUb
            Seli{m}{4} = [22 31:32]; % sz st and su
            Seli{m}{5} = [30 34]; %brange sTev 
            MDUindex{m} = 16:21;
            bdurindx{m} = 30;
            
            psel{m}{1, 1} = {[1 1 1], [1 1 1], [1 1 1]};%Motor times
            psel{m}{2, 1} = {[0 0 0], [0 0 0],  [0 0 0]}; %MDU
            psel{m}{3, 1} = {[0 0 0], [0 0 0], [0 0 0]}; %MDUb
            psel{m}{4, 1} = {[0 1 1], [0 1 1], [1 1 1]}; %variability
            psel{m}{5, 1} = {[0 0],   [0 1], [0 0]};  %% burst range sTev 
            
            checkselzero{m} = [22  31:32 34];  %If fixed, set these params to zero
           
        case 4 %SustSE
     
            par_range = [zeros(12,2);...  % First 12 parameters fixed by neural data
                0.05 0.095; ...             %13 mT 1
                0.05 0.095; ...             %14 mT 2
                0.05 0.095; ...             %15 mT 3
                0.5 1.5; ...                %16 MDU 1
                0.5 1.5; ...                %17 MDU 2
                0.5 1.5; ...                %18 MDU 3
                -0.5 1;...           % 19 MDUb 1
                -0.5 1;...           % 20 MDUb 2
                -0.5 1;...           % 21 MDUb 3
                0 0.2;...           % 22 sz
                0 25;...             % 23 d(1)
                0 25;...             % 24 d(2)
                0 10;...              %25  dC(1)
                0 10;...              %26  dC (2)
                0 10;...              %27  dC (3)
                0 3;...            % 28 s1  increasing noise
                0.09 0.1; ... %29 Tac accumulation onset time
                0 0.2; ...  %30 st
                0 0.5; ...   %31 su
                0 0.25; ...   %32 Tev evidence onset (relative to accumulaton onset time)
                0 0.2];   %33 sTev
            
            
            
            model_versions{m} = {'_su_st', '_sz_su_st', '_sTev_su_st'};
            urgency_mode = [1 1 1]; %urgency params all fixed
            swap_mode = ones(1, length(model_versions{m})); %no constraints swap
            
                    
            sps =[Gp_sp750_contra(1:3)'; Gp_sp750_ipsi(1:3)']; %Beta startpoints,  contra and ipsi to high value
            Fixed_params = [sps(:)' 750/1000*ones(1,6)];   %startpoints all set at 750ms post value cue
            
            
            Seli{m}{1} = 13:15; %motor times
            Seli{m}{2} = 16:18; %MDU
            Seli{m}{3} = 19:21; %MDUb
            Seli{m}{4} = [22 30 31 33]; % su st  su sTev
          
            
            MDUindex{m} = 16:21;
            
            psel{m}{1, 1} = {[1 1 1 ], [1 1 1 ], [1 1 1 ]};%Motor times
            psel{m}{2, 1} = {[0 0 0], [0 0 0], [0 0 0]}; %MDU
            psel{m}{3, 1} = {[0 0 0], [0 0 0], [0 0 0]}; %MDUb
            psel{m}{4, 1} = {[0 1 1 0],[1 1 1 0],[0 1 1 1]}; %variability
           
            checkselzero{m} = [22 25:27 30:31 33];  %If fixed, set these params to zero
            bdurindx{m}=[];
            
            
        case 5  %%DDM
            %%[b(1),b(2),b(3),z(1),z(2),z(3),d(1),d(2), Ter(1), Ter(2), Ter(3),sz,st,eta, N, seed]
              par_range = [0.01 3;...  %1  b1
                0.01 3; ... %2 b2
                0.01 3; ... %3 b3
                -1 1; ... %%4 z1
                -1 1; ...  % 5 z2
                -1 1; ...   %6 z3
                0 7; ... %7 d1
                0 7; ... % 8 d2
                0.02 0.4; ...  %9 Ter1
                0.02 0.4; ...  %10 Ter2
                0.02 0.4; ...   %11 Ter3
                0 1; ...  %12 sz
                0 .3; ...  %13 st
                0 7];  %14 eta
            urgency_mode = 0;  
            Fixed_params =[];
            Seli{m}=[];
            bdurindx{m}=[];
            MDUindex{m}=[];
            swap_mode=0;
            model_versions{m} = {''};
    end
    
    if m==5
         modelname = ['simul_' model{m}];
    else
    modelname = ['simul_NI_' model{m}];
    end
    for vi = versionstorun
        for stage = stages  %%how many runs
            
            %%Set the urgency slopes: high value and bias, for each
            %%regime
            clear MDU
            switch urgency_mode(vi)
                case 1
                    MDU = [Gp_Slope(:,1)' Gp_Slope(:,2)'-Gp_Slope(:,1)']; % FIxed both
                case 2
                    MDU = [Gp_Slope(:,1)' 0 0 0]; % No bias
                case 0
                    MDU =[];
            end
            
            startpms = [zeros(1,size(par_range,1))  sum(clock)];  %Last parameter is the random seed
            startpms(MDUindex{m}) = MDU;
            if ~isempty(bdurindx{m})
                startpms(bdurindx{m}) = 0.072;  %%72 ms burst duration
            end
            N = 20000*ones(4,2);  %%Number of simulations per condition
            
            Sel = [ones(1,size(par_range,1)) 0];  %Indicates estimated vs fixed parameters
            Sel(1:length(Fixed_params) ) = 0; %First 12 parameters fixed for all NI models
            pm = startpms(1,:);
            pm(Sel(1:end-1)==0) = Fixed_params;  %%These are the starting levels and start times: fixed for all NI models
            for pi = 1:length(Seli{m})  %Specific set of fixed parameters for each model version
                Sel(Seli{m}{pi}) = psel{m}{pi, 1}{vi};
            end
            
            %%If swap_mode is on, reorder fixed parameters
            if swap_mode(vi)>0
            neworder = fixed_param_mix{swap_mode(vi)};
            pm(1:length(neworder)) = pm(neworder);
            end
            %optimisation
            options = optimoptions('particleswarm','UseParallel',true, 'SwarmSize', 10*sum(Sel));
            [p,E] = particleswarm(@(p) G2(p,pm(Sel==0),Sel, N, gdat,qps,modelname), sum(Sel), par_range((Sel==1),1)',par_range((Sel==1),2)', options);
            
            pm(Sel==1) = p;
            % once search has ended, display value of the objective (error) function E, and parameters:
            disp(['E=' num2str(E) ' pm = ' num2str(pm)])
            
            % save them:
                 
            E_ave= E;
            pm_ave = pm;
            %recalculate G2 with a new seed and more simulations.
            pm(end) = sum(clock);
           
            E_cross = G2(pm(Sel==1),pm(Sel==0),Sel, N*100, gdat,qps,modelname);
            
            save(['JK' num2str(S_jk) '_' num2str(stage) '_paramfits_' modelnames{m} model_versions{m}{vi}],'pm_ave','E_ave', 'E_cross','startpms', 'Sel', 'Dat', 'par_range');
            %plot_ave_fit(model{m}, [modelnames{m} model_versions{m}{ver}], Dat, E_cross)
            % view_params_NI( [modelnames{m} model_versions{m}{ver}], Seli{m}, E_cross,m);
        end
    end
end



