function simdat = simul_DDM(pvar, pfix, Sel, N)

% parameter vector is passed in as two separate ones, listing the fixed and the free ones
% There are no fixed parameters in the DDM model fitting except the random
% seed

% simulation function for full DDM, no drift rate bias
% parameters:
% b = bound height. +b/-b = correct/incorrect bounds
% z = starting point bias
% d = drift rate
% Ter = nondecision time
% sz = intertrial range of starting point (range of uniform dist)
% st = intertrial range of nondecision time - uniform dist
% eta = between-trial var in drift rate


pm = zeros(1,15); % 14 parameters plus  the seed
pm(Sel==1) = pvar;
pm(Sel==0) = pfix;

% Pull the parameter values out of the input parameter vector:
[b(1),b(2),b(3),z(1),z(2),z(3),d(1),d(2), Ter(1), Ter(2), Ter(3),sz,st,eta, seed] = deal(pm(1),pm(2),pm(3),pm(4),pm(5),pm(6),pm(7),pm(8),pm(9),pm(10),pm(11),pm(12), pm(13), pm(14), pm(15));


Ter(4) = Ter(3);

if seed~=0
    rng(seed);
end

b_c = [b(1) b(1); b(2) b(2); b(3) b(3); b(3) b(3)]; % bound per regime ('c' (for condition) is counter var always used for regime)
d_c = [d(1) d(1); d(2) d(2); d(1) d(1); d(2) d(2)]; % drift rate per regime. Seems odd cos d and b already are per regime, but designed to be easily changeable for other options (e.g. only one d.r. per coherence)
z_vc = [z(1) -z(1);z(2) -z(2);z(3) -z(3); z(3) -z(3)]; % the mean starting point for each of the 9 total conditions (Regime x cue validity)

s = 0.1; % within-trial noise - scaling parameter

dt = 0.001;   % time step
T=0.8;
t = [-.2:dt:T]; %
for i=1:size(N,1) % condition
    
    rt = nan(sum(N(i,:)),1); %response time
    ch = nan(sum(N(i,:)),1); %choice
    val = [ones(N(i,1),1); 2*ones(N(i,2),1)];
    
    for v = 1:size(N,2) %value condition
         for n=1:N(i,v) % each single trial
            index= n; % just to figure out which row in the overall simulated data matrix we will b eentering this trial
            for j = 1:v-1
                index = index + N(i,j);
            end
            
            % simulate trial - 'tt' stands for 'this trial'
            dtt = d_c(i,v)+randn*eta; % drift rate variability around the mean for this condition
            btt = b_c(i,v); % bound
            Tertt = Ter(i) + (rand-.5)*st; % non decisoin time
            ztt = z_vc(i,v) + (rand-0.5)*sz;  % starting point
            
            % Make noisy evidence for this trial:
            noisyEv = [zeros(1,length(find(t<Tertt))) dtt*dt+randn(1,length(find(t>=Tertt)))*s*sqrt(dt)];
            DV = ztt + cumsum(noisyEv); % starting point + cumulative sum
            
            t1 = t(find(DV>btt,1));
            t2 = t(find(DV<-btt,1));
            if isempty(t1) & isempty(t2), rt(index,1) = nan; ch(index,1)=2; % miss
            elseif ~isempty(t1) & isempty(t2), rt(index,1) = t1; ch(index,1)=1;
            elseif isempty(t1) & ~isempty(t2), rt(index,1) = t2; ch(index,1)=0;
            else, if t1<=t2, ch(index,1)=1; else, ch(index,1)=0; end % CHoice: 1=correct, 0=error
                rt(index,1) = min(t1,t2); end
        end
        
    end
    RT{i} =  rt;
    CH{i} =  ch;
    V{i} = val;
   
end

% simulated data matrix to be returned:

simdat=zeros(sum(sum(N)),4);
index=1;
for c=1:size(N,1) %% Condition
    
    simdat(index:index+sum(N(c,:))-1,:) = [c*ones(sum(N(c,:)),1) V{c} CH{c} RT{c}];
    index = index+sum(N(c,:));
end
