function simdat = simul_NI_BurstSE(pvar, pfix, Sel, N)  %%delayed noise.
%%% Neurally constrained %%%
% parameters:
% 1:6 MB = starting levels Condition (hicoh, locoh, interleaved) x Value
% (high, low) Constrained by Beta
% 7:12 tMB = timepoints corresponding with starting levels (in seconds, relative
% to cue onset (fixed at 0.75 for all starting levels).
% 13:15 mT: motor times (hicoh, locoh, interleaved)
% 16:18 MDU = slope of dynamic urgency at the motor level (prop. to bound /sec)
% for high value trials, (hicoh, locoh, interleaved). 
% 19:21 MDUb = bias in MDU(Get low-value urgency from  high-value MDU+MDUb)
% 22 sz = start point variability at the motor level applied independently to both sides - full width of uniform distribution
% 23:24 d = drift rate - one per coherence.
% 25:27 dc = drift rate bias (added and subtracted to hival and loval
% respectively), one per regime.
% - applied at onset of accumulation for burst duration
% 28 s1 = gaussian noise /sec at accumulator level
% 29 Tac = Onset of evidence /  bias accumulation relative to the stimulus
% onset
% 30 burstrange = range of durations for the bias Burst (fixed @ 0.72)
% 31 st = intertrial range of motor time - uniform dist. 
% 32 su = between-trial var in urgency rate, applied independently to
% both sides
% 33 Tev = time at which sensory evidence starts impacting on the sensory
%  relative to Tac
% 34 sTev  = intertrial range of evidence onset time - uniform dist.
% 35 Seed = Random number generator seed.


% Assemble parameter vector.
np = length(Sel);
pm = zeros(1,np);
pm(Sel==1) = pvar;
pm(Sel==0) = pfix;

bound=1;
%%If these parameters are not being estimated (Sel==0) then make sure they
%%are set to zero.
checkselzero = [22 31:32 34];
pm(checkselzero(Sel(checkselzero)==0)) = 0;


[MB(1,1), MB(1,2), MB(2,1), MB(2,2), MB(3,1), MB(3,2), tMB(1,1), tMB(1,2), tMB(2,1), tMB(2,2), tMB(3,1), tMB(3,2), mT(1), mT(2), mT(3), ...
    MDU(1), MDU(2), MDU(3), MDUb(1), MDUb(2), MDUb(3), sz, d(1), d(2), dc(1), dc(2), dc(3), s1, Tac, burstrange, st, su, Tev, sTev, seed] ...
    = deal(pm(1),pm(2),pm(3),pm(4),pm(5),pm(6),pm(7),pm(8),pm(9),pm(10),pm(11),pm(12),pm(13),pm(14),pm(15),pm(16),pm(17),pm(18),pm(19), pm(20), ...
    pm(21),pm(22),pm(23),pm(24),pm(25),pm(26),pm(27),pm(28),pm(29), pm(30), pm(31),pm(32),pm(33),pm(34),pm(35));

if seed~=0
    rng(seed);
end

%%motor times & starting levels- same for both interleaved conditions
mT(4) = mT(3);
MB(4,:) = MB(3,:);
tMB(4,:) = tMB(3,:);

%assemble drift rate, drift bias and dynamic urgency matrices (condition x
%value)
drift = [d(1) d(1); d(2) d(2); d(1) d(1); d(2) d(2)];
db = [dc(1) -dc(1); dc(2) -dc(2); dc(3) -dc(3); dc(3) -dc(3)];
DU = [MDU' MDU'+MDUb'; MDU(3) MDU(3)+MDUb(3)];

dt = 0.001;
T=0.8;
t = [-.2:dt:T]; %time vector


for i=1:size(N,1) % condition
    
    rt = nan(sum(N(i,:)),1); %response time
    ch = nan(sum(N(i,:)),1); % choice
    val = [ones(N(i,1),1); 2*ones(N(i,2),1)]; %value
    for v = 1:size(N,2) %value condition
        soa = [zeros(1, N(i,v)/2) .05*ones(1, N(i,v)/2)]; %%SOA: stimulus onsets 50ms later in half of trials
        for n=1:N(i,v)
            % simulate trial
            
            index= n;
            for j = 1:v-1
                index = index + N(i,j);
            end
            evidence = zeros(1,length(t));
            bias = zeros(1,length(t));
            startAccT =  Tac + soa(n) ; % onset of bias accumulation
            evT = (Tac +Tev + (rand-0.5)*sTev + soa(n)); % onset of noisy sensory evidence accumulation
            evidence((t>evT )) = 1;
            
            bias(t>=(startAccT) & t<=(startAccT+ rand*burstrange)) = 1;
                       
            u1 = MB(i,v) + (DU(i,v) + su*randn)*(t+0.85-tMB(i,v)); u1 = max(0,u1) + (rand-.5)*sz; %Motor level for correct
            u2 = MB(i,3-v) + (DU(i,3-v)+ su*randn)*(t+0.85-tMB(i,3-v)); u2 = max(0,u2) + (rand-.5)*sz; %Motor level for error
            dtt = drift(i, v);  %drift this trial
            dbtt = db(i, v);  %drift bias this trial

            noise = [zeros(1,length(find(t<=evT))) randn(1,length(find(t>evT))).*s1*sqrt(dt)];
            
            ev=evidence;
            ev((t<startAccT))=0;
            bias((t<startAccT))=0;
            noise((t<startAccT))=0;
            cpp = cumsum(ev*dtt*dt +  bias*dbtt*dt + noise); %sensory level accumulator (CPP)
            
            %decision variables
            DV1 = u1   +max([zeros(size(cpp));cpp]); % Add the half-wave-rectified CPP
            DV2 = u2 + max([zeros(size(cpp));-cpp]);
            
            t1 = t(find(DV1>bound,1));
            t2 = t(find(DV2>bound,1));
            
            if isempty(t1) & isempty(t2), rt(index,1) = nan; ch(index,1)=2; %miss
            elseif ~isempty(t1) & isempty(t2), rt(index,1) = t1; ch(index,1)=1;
            elseif isempty(t1) & ~isempty(t2), rt(index,1) = t2; ch(index,1)=0;
            else, if t1<=t2, ch(index,1)=1; else, ch(index,1)=0; end % CHoice: 1=correct, 0=error
                rt(index,1) = min(t1,t2); end
            rt(index,1) = rt(index,1)+mT(i)+(rand-.5)*st - soa(n);  % add motor time and subtract soa
            
            
        end
    end
    soa = [zeros(1, N(i,1)/2) .05*ones(1, N(i,1)/2) zeros(1, N(i,2)/2) .05*ones(1, N(i,2)/2)]';
    RT{i} =  rt;
    CH{i} =  ch;
    V{i} = val;
    SOA{i} = soa;
    
end
simdat=zeros(sum(sum(N)),5);
index=1;
for c=1:size(N,1) %% Condition
    
    simdat(index:index+sum(N(c,:))-1,:) = [c*ones(sum(N(c,:)),1) V{c} CH{c} RT{c} SOA{c}];
    index = index+sum(N(c,:));
end
